Description of Metadata
=======================

Project:
    __name__
    __display_name__
    __description__
    __creation_date__
    __folder__
    custom metadata fields...

Collection:
    __name__
    __display_name__
    __description__
    __creation_date__
    custom metadata fields...

Feature:
    __name__
    __display_name__
    __description__
    __type__ = service/created
    __external_id__ = external uid
    __external_parameters__ = externally available parameters
    __datasets__
    custom metadata fields...

Dataset:
    __name__
    __display_name__
    __description__
    __history__
    __classification__
    __quest_ver__
    __path__
    __parameters__ = {'code': {group:,name:,unit}}
    custom metadata fields...
